<?php
/*
Plugin Name: Easy Admin Color Schemes
Plugin URI: http://www.jamesdimick.com/creations/easy-admin-color-schemes/
Description: The Easy Admin Color Schemes plugin allows users to easily customize the colors of the administration interface for WordPress. It works by adding a new page to the Settings area in the WordPress admin interface. Users can use the simple form to change the look of the admin interface without needing to know a great deal about WordPress. The plugin generates a new stylesheet file for each color scheme created. This allows for seamless integration with the color scheme functions already available in the WordPress 2.5+ core.
Version: 1.8
Author: James Dimick
Author URI: http://www.jamesdimick.com/

=== VERSION HISTORY ===
  04.18.08 - v1.0 - The first version
  04.20.08 - v1.1 - Changed some URL query variable names in an attempt to prevent clashing with other plugins
  04.21.08 - v1.2 - Changed the way Last Modified dates are handled so the plugin still works instead of erroring out
  04.22.08 - v1.3 - Fixed an issue with slashes in the CSS content when you save a scheme
  04.23.08 - v1.4 - Added a better-looking default color scheme called Washedout
  04.23.08 - v1.5 - Added error codes to aid in debugging and fixed some image issues with the new Washedout color scheme
  04.26.08 - v1.6 - Added a link to the user profile page right by the Admin Color Scheme selector which links to the plugin
  04.26.08 - v1.7 - Fixed the way the new link on the profile page works so only users with proper permissions can see it
  04.29.08 - v1.8 - Corrected some things to allow for better localization

=== TO DO LIST ===
  0. Nothing right now...

=== LEGAL INFORMATION ===
  Copyright (C) 2008 James Dimick <mail@jamesdimick.com> - www.jamesdimick.com

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program. If not, see <http://www.gnu.org/licenses/>.
*/

$eacs_domain = 'easy-admin-color-schemes';
load_plugin_textdomain($eacs_domain, 'wp-content/plugins/easy-admin-color-schemes');
add_action('admin_init', 'eacs_css_files');
add_action('admin_init', 'eacs_process_request');
add_action('admin_menu', 'eacs_add_settings_page');
if($_GET['page'] == 'easy-admin-color-schemes') { add_action('admin_head', 'eacs_admin_head'); wp_enqueue_script('colorpicker'); }

function eacs_process_request() {
	if(isset($_POST['eacsubmit']) || isset($_GET['eacsaction']) && $_GET['eacsaction'] != 'edit') {
		global $_wp_admin_css_colors;
		$cssfiles = eacs_css_files();

		function isempty($var) {
			$var = trim($var);
			if(!isset($var) || empty($var)) return true; else return false;
		}

		if(isset($_POST['eacsubmit'])) {
			if(function_exists('current_user_can') && current_user_can('manage_options')) {
				$schemedir = dirname(__FILE__).'/schemes/';
				$action = trim($_POST['eacsaction']);
				$schemename = trim(stripslashes($_POST['schemename']));
				$cleanschemename = sanitize_title($schemename);
				$schemefile = $schemedir.$cleanschemename.'.css';
				$priclrtxt1 = trim($_POST['priclrtxt1']);
				$priclrtxt2 = trim($_POST['priclrtxt2']);
				$priclrtxt3 = trim($_POST['priclrtxt3']);
				$priclrtxt4 = trim($_POST['priclrtxt4']);
				$schemecss = trim(stripslashes($_POST['schemecss']));

				if(!is_writable($schemedir)) die(__('Easy Admin Color Schemes - Error accessing directories! (Error Code: 1)', $eacs_domain));

				if(isempty($schemename) && isempty($priclrpck1) && isempty($priclrpck2) && isempty($priclrpck3) && isempty($priclrpck4) && isempty($schemecss)) {
					wp_redirect(get_option('siteurl').'/wp-admin/options-general.php?page=easy-admin-color-schemes&msg=7'); exit;
				}

				if($action == 'add') {
					if(!file_exists($schemefile)) {
						if(!$cssfiles[$cleanschemename] && !$_wp_admin_css_colors[$cleanschemename]) {
							if(preg_match('/^[a-zA-Z0-9 \-\._\'"\?\!]{3,40}$/i', $schemename) && preg_match('/^\#[a-fA-F0-9]{6}$/i', $priclrtxt1) && preg_match('/^\#[a-fA-F0-9]{6}$/i', $priclrtxt2) && preg_match('/^\#[a-fA-F0-9]{6}$/i', $priclrtxt3) && preg_match('/^\#[a-fA-F0-9]{6}$/i', $priclrtxt4)) {
								$nfc = "/*\r\n".'Scheme Name: '.$schemename."\r\n".'Primary Colors: '.str_replace('#', '', $priclrtxt1).'|'.str_replace('#', '', $priclrtxt2).'|'.str_replace('#', '', $priclrtxt3).'|'.str_replace('#', '', $priclrtxt4)."\r\n*/\r\n".$schemecss;
								$sf = @fopen($schemefile, 'wb') or die(__('Easy Admin Color Schemes - Error creating files! (Error Code: 2)', $eacs_domain));
								if(fwrite($sf, $nfc) === FALSE) die(__('Easy Admin Color Schemes - Error creating files! (Error Code: 3)', $eacs_domain));
								fclose($sf);
								wp_redirect(get_option('siteurl').'/wp-admin/options-general.php?page=easy-admin-color-schemes&msg=1'); exit;
							} else {
								wp_redirect(get_option('siteurl').'/wp-admin/options-general.php?page=easy-admin-color-schemes&msg=9'); exit;
							}
						} else {
							wp_redirect(get_option('siteurl').'/wp-admin/options-general.php?page=easy-admin-color-schemes&msg=4'); exit;
						}
					} else {
						wp_redirect(get_option('siteurl').'/wp-admin/options-general.php?page=easy-admin-color-schemes&msg=4'); exit;
					}
				} elseif($action == 'edit') {
					$hiddename = trim($_POST['eacsname']);
					$schemefile = $schemedir.$hiddename.'.css';
					if(file_exists($schemefile)) {
						if($cssfiles[$hiddename]) {
							if(preg_match('/^\#[a-fA-F0-9]{6}$/i', $priclrtxt1) && preg_match('/^\#[a-fA-F0-9]{6}$/i', $priclrtxt2) && preg_match('/^\#[a-fA-F0-9]{6}$/i', $priclrtxt3) && preg_match('/^\#[a-fA-F0-9]{6}$/i', $priclrtxt4)) {
								$nfc = "/*\r\n".'Scheme Name: '.$cssfiles[$hiddename]['name']."\r\n".'Primary Colors: '.str_replace('#', '', $priclrtxt1).'|'.str_replace('#', '', $priclrtxt2).'|'.str_replace('#', '', $priclrtxt3).'|'.str_replace('#', '', $priclrtxt4)."\r\n*/\r\n".$schemecss;
								$sf = @fopen($schemefile, 'wb') or die(__('Easy Admin Color Schemes - Error creating files! (Error Code: 4)', $eacs_domain));
								if(fwrite($sf, $nfc) === FALSE) die(__('Easy Admin Color Schemes - Error creating files! (Error Code: 5)', $eacs_domain));
								fclose($sf);
								wp_redirect(get_option('siteurl').'/wp-admin/options-general.php?page=easy-admin-color-schemes&eacsaction=edit&eacsid='.$hiddename.'&msg=2'); exit;
							} else {
								wp_redirect(get_option('siteurl').'/wp-admin/options-general.php?page=easy-admin-color-schemes&msg=9'); exit;
							}
						} else {
							wp_redirect(get_option('siteurl').'/wp-admin/options-general.php?page=easy-admin-color-schemes&msg=5'); exit;
						}
					} else {
						wp_redirect(get_option('siteurl').'/wp-admin/options-general.php?page=easy-admin-color-schemes&msg=5'); exit;
					}
				} else {
					wp_redirect(get_option('siteurl').'/wp-admin/options-general.php?page=easy-admin-color-schemes&msg=6'); exit;
				}
			} else {
				die(__('Easy Admin Color Schemes - You do not have sufficient permission! (Error Code: 6)', $eacs_domain));
			}
		} elseif($_GET['eacsaction'] == 'use') {
			if(is_user_logged_in()) {
				if($_wp_admin_css_colors[$_GET['eacsid']]) {
					global $userdata;
					get_currentuserinfo();
					update_user_option($userdata->ID, 'admin_color', $_GET['eacsid']);
					wp_redirect(get_option('siteurl').'/wp-admin/options-general.php?page=easy-admin-color-schemes&msg=8'); exit;
				} else {
					wp_redirect(get_option('siteurl').'/wp-admin/options-general.php?page=easy-admin-color-schemes&msg=5'); exit;
				}
			} else {
				die(__('Easy Admin Color Schemes - You do not have sufficient permission! (Error Code: 7)', $eacs_domain));
			}
		} elseif($_GET['eacsaction'] == 'delete') {
			if(function_exists('current_user_can') && current_user_can('manage_options')) {
				if($cssfiles[$_GET['eacsid']]) {
					@unlink($cssfiles[$_GET['eacsid']]['file']) or die(__('Easy Admin Color Schemes - Error deleting file! (Error Code: 8)', $eacs_domain));
					wp_redirect(get_option('siteurl').'/wp-admin/options-general.php?page=easy-admin-color-schemes&msg=3'); exit;
				} else {
					wp_redirect(get_option('siteurl').'/wp-admin/options-general.php?page=easy-admin-color-schemes&msg=5'); exit;
				}
			} else {
				die(__('Easy Admin Color Schemes - You do not have sufficient permission! (Error Code: 9)', $eacs_domain));
			}
		} else {
			if(function_exists('current_user_can') && current_user_can('manage_options')) {
				wp_redirect(get_option('siteurl').'/wp-admin/options-general.php?page=easy-admin-color-schemes&msg=6'); exit;
			} else {
				die(__('Easy Admin Color Schemes - You do not have sufficient permission! (Error Code: 10)', $eacs_domain));
			}
		}
	}
}

function eacs_css_files() {
	global $_wp_admin_css_colors;
	clearstatcache();
	$scheme_dir = dirname(__FILE__).'/schemes/';
	$dir = @opendir($scheme_dir) or die(__('Easy Admin Color Schemes - Error accessing directories! (Error Code: 11)', $eacs_domain));

	while($file = readdir($dir)) {
		if($file != '.' || $file != '..') {
			if(preg_match('/^(.+)\.css$/i', $file)) {
				$file_contents = @file_get_contents($scheme_dir.$file) or die(__('Easy Admin Color Schemes - Error accessing files! (Error Code: 12)', $eacs_domain));

				if(preg_match('/^\/\*[\n\r]+Scheme Name: ([a-zA-Z0-9 \-\._\'"\?\!]{3,40})[\n\r]+Primary Colors: ([a-fA-F0-9]{6})[\|]([a-fA-F0-9]{6})[\|]([a-fA-F0-9]{6})[\|]([a-fA-F0-9]{6})[\n\r]+\*\/(.+)$/is', $file_contents, $matches)) {
					$clean_title = sanitize_title(trim($matches[1]));

					if(!$_wp_admin_css_colors[$clean_title]) {
						wp_admin_css_color($clean_title, $matches[1], get_option('siteurl').'/'.PLUGINDIR.'/easy-admin-color-schemes/schemes/'.$file, array('#'.$matches[2], '#'.$matches[3], '#'.$matches[4], '#'.$matches[5]));
					}

					if(!$result[$clean_title]) {
						$result[$clean_title] = array('name' => $matches[1], 'file' => $scheme_dir.$file, 'color1' => '#'.$matches[2], 'color2' => '#'.$matches[3], 'color3' => '#'.$matches[4], 'color4' => '#'.$matches[5], 'content' => $matches[6]);
					}
				}
			}
		}
	}

	@closedir($dir);
	return($result);
}

function eacs_admin_head() { ?>
	<link rel="stylesheet" type="text/css" href="<?php echo(get_option('siteurl').'/'.PLUGINDIR.'/easy-admin-color-schemes/easy-admin-color-schemes.css') ?>" />
	<script type="text/javascript">
	// <![CDATA[
	var cp = new ColorPicker();
	function deleteConfirm(sn) {
		return confirm('<?php _e('Are you sure you want to delete the', $eacs_domain) ?> \"' + sn + '\" <?php _e('scheme?', $eacs_domain) ?>\n<?php _e('This action cannot be undone!', $eacs_domain) ?>');
	}
	function validate_form(thisform) {
		var namePatt = new RegExp('^[a-zA-Z0-9 \-\._\'"\?\!]{3,40}$', 'i');
		var colorPatt = new RegExp('^\#[a-fA-F0-9]{6}$', 'i');
		with(thisform) {
			if(schemename.value == null || schemename.value == '' || namePatt.test(schemename.value) == false) {
				schemename.focus(); alert('<?php _e('The scheme name is empty or invalid!', $eacs_domain) ?>'); return false;
			} else if(priclrtxt1.value == null || priclrtxt1.value == '' || colorPatt.test(priclrtxt1.value) == false) {
				priclrtxt1.focus(); alert('<?php _e('The first primary color is empty or invalid!', $eacs_domain) ?>'); return false;
			} else if(priclrtxt2.value == null || priclrtxt2.value == '' || colorPatt.test(priclrtxt2.value) == false) {
				priclrtxt2.focus(); alert('<?php _e('The second primary color is empty or invalid!', $eacs_domain) ?>'); return false;
			} else if(priclrtxt3.value == null || priclrtxt3.value == '' || colorPatt.test(priclrtxt3.value) == false) {
				priclrtxt3.focus(); alert('<?php _e('The third primary color is empty or invalid!', $eacs_domain) ?>'); return false;
			} else if(priclrtxt4.value == null || priclrtxt4.value == '' || colorPatt.test(priclrtxt4.value) == false) {
				priclrtxt4.focus(); alert('<?php _e('The fourth primary color is empty or invalid!', $eacs_domain) ?>'); return false;
			} else if(schemecss.value == null || schemecss.value == '') {
				schemecss.focus(); alert('<?php _e('The scheme CSS is empty or invalid!', $eacs_domain) ?>'); return false;
			}
		}
	}
	function PopupWindow_populate(contents) {
		contents += '<p style="text-align:center;margin-top:10px"><input type="button" value="<?php _e('Close Color Picker', $eacs_domain) ?>" onclick="cp.hidePopup(\'prettyplease\')" class="button-secondary" /><' + '/p>';
		this.contents = contents;
		this.populated = false;
	}
	function colorSelect(t, p) {
		var t = document.getElementById(t);
		if(cp.p == p && document.getElementById(cp.divName).style.visibility != 'hidden') {
			cp.hidePopup('prettyplease');
		} else {
			cp.p = p;
			cp.select(t, p);
		}
	}
	function insertColorPickerButtons() {
		var pckbtn1 = document.createElement('input'); pckbtn1.setAttribute('title', '<?php _e('Click to choose a color', $eacs_domain) ?>'); pckbtn1.setAttribute('class', 'button-secondary'); pckbtn1.setAttribute('onclick', "colorSelect('priclrtxt1','priclrpck1');return false;"); pckbtn1.setAttribute('value', '>'); pckbtn1.setAttribute('id', 'priclrpck1'); pckbtn1.setAttribute('name', 'priclrpck1'); pckbtn1.setAttribute('type', 'button');
		var pckbtn2 = document.createElement('input'); pckbtn2.setAttribute('title', '<?php _e('Click to choose a color', $eacs_domain) ?>'); pckbtn2.setAttribute('class', 'button-secondary'); pckbtn2.setAttribute('onclick', "colorSelect('priclrtxt2','priclrpck2');return false;"); pckbtn2.setAttribute('value', '>'); pckbtn2.setAttribute('id', 'priclrpck2'); pckbtn2.setAttribute('name', 'priclrpck2'); pckbtn2.setAttribute('type', 'button');
		var pckbtn3 = document.createElement('input'); pckbtn3.setAttribute('title', '<?php _e('Click to choose a color', $eacs_domain) ?>'); pckbtn3.setAttribute('class', 'button-secondary'); pckbtn3.setAttribute('onclick', "colorSelect('priclrtxt3','priclrpck3');return false;"); pckbtn3.setAttribute('value', '>'); pckbtn3.setAttribute('id', 'priclrpck3'); pckbtn3.setAttribute('name', 'priclrpck3'); pckbtn3.setAttribute('type', 'button');
		var pckbtn4 = document.createElement('input'); pckbtn4.setAttribute('title', '<?php _e('Click to choose a color', $eacs_domain) ?>'); pckbtn4.setAttribute('class', 'button-secondary'); pckbtn4.setAttribute('onclick', "colorSelect('priclrtxt4','priclrpck4');return false;"); pckbtn4.setAttribute('value', '>'); pckbtn4.setAttribute('id', 'priclrpck4'); pckbtn4.setAttribute('name', 'priclrpck4'); pckbtn4.setAttribute('type', 'button');
		document.getElementById('priclrs').insertBefore(pckbtn1, document.getElementById('priclrtxt1').nextSibling);
		document.getElementById('priclrs').insertBefore(pckbtn2, document.getElementById('priclrtxt2').nextSibling);
		document.getElementById('priclrs').insertBefore(pckbtn3, document.getElementById('priclrtxt3').nextSibling);
		document.getElementById('priclrs').insertBefore(pckbtn4, document.getElementById('priclrtxt4').nextSibling);
	}
	function insertColorPickerDiv() {
		var thediv = '<div id="colorPickerDiv">&nbsp;<' + '/div>';
		document.getElementById('priclrs').innerHTML += thediv;
	}
	function insertPreviewButton() {
		var btntbl = document.getElementById('schemeformtable').getElementsByTagName('tbody')[0].getElementsByTagName('tr')[2].getElementsByTagName('td')[0];
		var btn = '<input type="button" name="schemeprevupd" id="schemeprevupd" value="<?php _e('Update Preview', $eacs_domain) ?>" onclick="updatePreview();return false;" class="button-secondary" title="<?php _e('Click to update the live preview below', $eacs_domain) ?>" />';
		btntbl.innerHTML += btn;
	}
	function insertPreview() {
		var optbl = document.getElementById('schemeformtable').getElementsByTagName('tbody')[0];
		var newtr = document.createElement('tr');
		var newth = document.createElement('th');
		optbl.appendChild(newtr);
		var thetr = optbl.getElementsByTagName('tr')[3];
		thetr.vAlign = 'top';
		thetr.appendChild(newth);
		var theth = thetr.getElementsByTagName('th')[0];
		theth.className = 'th-full';
		theth.colSpan = 2;
		theth.scope = 'row';
		theth.innerHTML = '<span style="display:block;margin-bottom:10px"><?php _e('Live Preview', $eacs_domain) ?><' + '/span><iframe name="schemepreview" id="schemepreview" src="<?php echo(get_option('siteurl').'/wp-admin/') ?>" onload="updatePreview();return false;"><?php _e('Scheme Preview', $eacs_domain) ?><' + '/iframe>';
	}
	function updatePreview() {
		var innerCSS = document.getElementById('schemecss').value;
		with(document.getElementById('schemepreview').contentWindow) {
			var h = document.getElementsByTagName('head'); if(!h.length)return;
			var l = h[0].getElementsByTagName('link');
			var newStyleSheet = document.createElement('style');
			newStyleSheet.type = 'text/css';
			if(l.length)h[0].removeChild(l[2]);
			h[0].appendChild(newStyleSheet);
			try {
				newStyleSheet.styleSheet.cssText = innerCSS;
			} catch(e) {
				try {
					newStyleSheet.appendChild(document.createTextNode(innerCSS));
					newStyleSheet.innerHTML = innerCSS;
				} catch(e) {}
			}
		}
	}
	window.onload = function() { insertColorPickerButtons(); insertColorPickerDiv(); insertPreviewButton(); insertPreview(); };
	// ]]>
	</script>
<?php }

function eacs_add_settings_page() {
	function eacs_settings_page() {
		if(function_exists('current_user_can') && !current_user_can('manage_options')) die(__('Easy Admin Color Schemes - You do not have sufficient permission to manage options. (Error Code: 13)', $eacs_domain));
		global $_wp_admin_css_colors;
		$cssfiles = eacs_css_files();
		$default_scheme = @file_get_contents(ABSPATH.'/wp-admin/css/colors-fresh.css') or die(__('Easy Admin Color Schemes - Error accessing files! (Error Code: 14)', $eacs_domain));
		$current_scheme = $cssfiles[$_GET['eacsid']];
		$scheme_header = ($_GET['eacsaction'] == 'edit' && $current_scheme) ? __('Edit Color Scheme', $eacs_domain) : __('Add a Color Scheme', $eacs_domain);
		$scheme_headdesc = ($_GET['eacsaction'] == 'edit' && $current_scheme) ? __('Use the form below to edit the currently selected color scheme.', $eacs_domain) : __('You can fill out the simple form below to create a new scheme.', $eacs_domain);
		$scheme_name = ($_GET['eacsaction'] == 'edit' && $current_scheme) ? $current_scheme['name'] : 'My Cool Scheme';
		$scheme_nameclr = ($_GET['eacsaction'] == 'edit' && $current_scheme) ? '' : ' onfocus="if(this.value == \'My Cool Scheme\') { this.value=\'\'; }" onblur="if(this.value == \'\') { this.value=\'My Cool Scheme\'; }"';
		$scheme_namedis = ($_GET['eacsaction'] == 'edit' && $current_scheme) ? ' disabled="disabled"' : '';
		$scheme_priclr1 = ($_GET['eacsaction'] == 'edit' && $current_scheme) ? $current_scheme['color1'] : '#464646';
		$scheme_priclr2 = ($_GET['eacsaction'] == 'edit' && $current_scheme) ? $current_scheme['color2'] : '#CEE1EF';
		$scheme_priclr3 = ($_GET['eacsaction'] == 'edit' && $current_scheme) ? $current_scheme['color3'] : '#D54E21';
		$scheme_priclr4 = ($_GET['eacsaction'] == 'edit' && $current_scheme) ? $current_scheme['color4'] : '#2683AE';
		$scheme_css = ($_GET['eacsaction'] == 'edit' && $current_scheme) ? $current_scheme['content'] : $default_scheme;
		$scheme_hiddename = ($_GET['eacsaction'] == 'edit' && $current_scheme) ? '<input type="hidden" name="eacsname" id="eacsname" value="'.sanitize_title($scheme_name).'" />' : '';
		$scheme_action = ($_GET['eacsaction'] == 'edit' && $current_scheme) ? 'edit' : 'add';
		$scheme_submitval = ($_GET['eacsaction'] == 'edit' && $current_scheme) ? __('Save Scheme', $eacs_domain) : __('Add Scheme', $eacs_domain);

		if(isset($_GET['msg'])) {
			if($_GET['msg'] == '1') { ?>
				<div id="eacsmsg" class="updated fade"><p><strong><?php _e('Your new color scheme has been added!', $eacs_domain) ?></strong></p></div>
			<?php } elseif($_GET['msg'] == '2') { ?>
				<div id="eacsmsg" class="updated fade"><p><strong><?php _e('Your chnages to the color scheme have been saved!', $eacs_domain) ?></strong></p></div>
			<?php } elseif($_GET['msg'] == '3') { ?>
				<div id="eacsmsg" class="updated fade"><p><strong><?php _e('You have successfully deleted the color scheme!', $eacs_domain) ?></strong></p></div>
			<?php } elseif($_GET['msg'] == '4') { ?>
				<div id="eacsmsg" class="error"><p><strong><?php _e('The color scheme you were trying to add already exists!', $eacs_domain) ?></strong></p></div>
			<?php } elseif($_GET['msg'] == '5') { ?>
				<div id="eacsmsg" class="error"><p><strong><?php _e('The provided scheme is not a valid color scheme!', $eacs_domain) ?></strong></p></div>
			<?php } elseif($_GET['msg'] == '6') { ?>
				<div id="eacsmsg" class="error"><p><strong><?php _e('The action provided is incorrect!', $eacs_domain) ?></strong></p></div>
			<?php } elseif($_GET['msg'] == '7') { ?>
				<div id="eacsmsg" class="error"><p><strong><?php _e('Your submission had missing required items!', $eacs_domain) ?></strong></p></div>
			<?php } elseif($_GET['msg'] == '8') { ?>
				<div id="eacsmsg" class="updated fade"><p><strong><?php _e('Your current color scheme has been changed!', $eacs_domain) ?></strong></p></div>
			<?php } elseif($_GET['msg'] == '9') { ?>
				<div id="eacsmsg" class="error"><p><strong><?php _e('Your submission had invalid required items!', $eacs_domain) ?></strong></p></div>
			<?php }
		} ?>
		<div class="wrap">
			<h2 id="all-schemes"><?php _e('Color Schemes', $eacs_domain) ?></h2>
			<div class="section">
				<p><?php _e('Below you will find a list of all currently existing color schemes. You can add more by going down to the <a href="'.get_option('siteurl').'/wp-admin/options-general.php?page=easy-admin-color-schemes#scheme-input" title="Add a color scheme">Add a Color Scheme</a> area.', $eacs_domain) ?></p>
				<table class="widefat" id="the-scheme-list">
					<thead>
						<tr>
							<th scope="col"><?php _e('Scheme', $eacs_domain) ?></th>
							<th scope="col" style="width:20%"><?php _e('Last Modified', $eacs_domain) ?></th>
							<th scope="col" style="text-align:right;width:20%"><?php _e('Actions', $eacs_domain) ?></th>
						</tr>
					</thead>

					<tbody>
						<?php if($_wp_admin_css_colors) {
							$current_user_admin_color = (get_user_option('admin_color')) ? get_user_option('admin_color') : 'fresh';

							foreach($_wp_admin_css_colors as $color => $color_info) {
								$schemeurl = @parse_url($color_info->url);
								$schemepath = @realpath('..'.$schemeurl['path']);
								$schememodtime = @filemtime($schemepath);
								$schememodate = ($schememodtime) ? date('Y/m/d \a\\t g:iA', $schememodtime) : 'Unknown'; ?>
								<tr>
									<td class="eacs-schemes-colors"><?php foreach($color_info->colors as $html_color) { ?><span style="background-color:<?php echo($html_color) ?>">&nbsp;</span><?php } ?><strong><?php echo($color_info->name) ?></strong></td>
									<td style="width:20%"><?php _e($schememodate, $eacs_domain) ?></td>
									<td style="text-align:right;width:20%"><?php $use_link = ($color != $current_user_admin_color) ? '<a href="'.get_option('siteurl').'/wp-admin/options-general.php?page=easy-admin-color-schemes&amp;eacsaction=use&amp;eacsid='.$color.'" title="'.__('Use this color scheme now', $eacs_domain).'">'.__('Use', $eacs_domain).'</a>' : '<span class="nonessential">'.__('Use', $eacs_domain).'</span>';

									if($cssfiles[$color]) {
										$edit_link = ($_GET['eacsaction'] == 'edit' && $_GET['eacsid'] == $color) ? '<span class="nonessential">'.__('Edit', $eacs_domain).'</span>' : '<a href="'.get_option('siteurl').'/wp-admin/options-general.php?page=easy-admin-color-schemes&amp;eacsaction=edit&amp;eacsid='.$color.'#scheme-input" title="'.__('Edit this color scheme', $eacs_domain).'">'.__('Edit', $eacs_domain).'</a>';
										$delete_link = '<a href="'.get_option('siteurl').'/wp-admin/options-general.php?page=easy-admin-color-schemes&amp;eacsaction=delete&amp;eacsid='.$color.'" title="'.__('Delete this color scheme', $eacs_domain).'" class="delete" onclick="return deleteConfirm(\''.addslashes($color_info->name).'\');">'.__('Delete', $eacs_domain).'</a>';
									} else {
										$edit_link = '<span class="nonessential">'.__('Edit', $eacs_domain).'</span>';
										$delete_link = '<span class="nonessential">'.__('Delete', $eacs_domain).'</span>';
									}

									echo($use_link.' | '.$edit_link.' | '.$delete_link); ?></td>
								</tr>
							<?php }
						} else { ?>
							<tr>
								<td colspan="3"><strong><?php _e('There are currently no color schemes! Add some below&hellip;', $eacs_domain) ?></strong></td>
							</tr>
						<?php } ?>
					</tbody>
				</table>
			</div>


			<h2 id="scheme-input" style="margin-top:2em"><?php echo($scheme_header) ?></h2>
			<div class="section">
				<p><?php echo($scheme_headdesc) ?> <?php _e('Also, if JavaScript is enabled in your browser, there is a live preview function.', $eacs_domain) ?></p>
				<form method="post" action="<?php echo(get_option('siteurl')) ?>/wp-admin/options-general.php?page=easy-admin-color-schemes" onsubmit="return validate_form(this);">
					<table id="schemeformtable" class="form-table">
						<tbody>
							<tr valign="top">
								<th scope="row"><label for="schemename"><?php _e('Scheme Name', $eacs_domain) ?></label></th>
								<td><input type="text" name="schemename" id="schemename" value="<?php echo($scheme_name) ?>" size="50" maxlength="40"<?php echo($scheme_namedis.$scheme_nameclr) ?> /></td>
							</tr>

							<tr valign="top">
								<th scope="row"><label for="priclrtxt1"><?php _e('Primary Colors', $eacs_domain) ?></label></th>
								<td id="priclrs"><input type="text" name="priclrtxt1" id="priclrtxt1" value="<?php echo($scheme_priclr1) ?>" size="8" maxlength="7" class="code" />&emsp;<input type="text" name="priclrtxt2" id="priclrtxt2" value="<?php echo($scheme_priclr2) ?>" size="8" maxlength="7" class="code" />&emsp;<input type="text" name="priclrtxt3" id="priclrtxt3" value="<?php echo($scheme_priclr3) ?>" size="8" maxlength="7" class="code" />&emsp;<input type="text" name="priclrtxt4" id="priclrtxt4" value="<?php echo($scheme_priclr4) ?>" size="8" maxlength="7" class="code" /></td>
							</tr>

							<tr valign="top">
								<th scope="row"><label for="schemecss"><?php _e('Scheme CSS', $eacs_domain) ?></label></th>
								<td><textarea name="schemecss" id="schemecss" cols="50" rows="20" class="code"><?php echo($scheme_css) ?></textarea></td>
							</tr>
						</tbody>
					</table>
					<p class="submit"><?php echo($scheme_hiddename) ?><input type="hidden" name="eacsaction" id="eacsaction" value="<?php echo($scheme_action) ?>" /><input type="submit" name="eacsubmit" id="eacsubmit" value="<?php echo($scheme_submitval) ?>" class="button" onclick="cp.hidePopup('prettyplease');" /></p>
				</form>
			</div>


			<h2 id="more-info" style="margin-top:2em"><?php _e('More Information', $eacs_domain) ?></h2>
			<div class="section">
				<p><?php _e('This plugin allows you to manage the color schemes for the administration interface of this site. You can add, edit, and delete any scheme that is compatible with this plugin. The interface is fairly straightforward but, if you have any issues please <a href="http://www.jamesdimick.com/contact/">get in contact with the author</a>. Also, please report any bugs, errors, or just anything that you would like at <a href="http://www.jamesdimick.com/creations/easy-admin-color-schemes/">the official plugin page</a>. Finally, if you like this plugin and would like to help support it&rsquo;s development, you can <a href="http://www.jamesdimick.com/donate/">donate to the author</a>. Donations are <strong>very</strong> much appreciated and they will all go to making this plugin better!', $eacs_domain) ?></p>
			</div>
		</div>
	<?php }

	function eacs_manage_schemes_link() {
		if(function_exists('current_user_can') && current_user_can('manage_options')) { ?>
			<p style="position:absolute;margin:14em 0 0 25px"><a href="<?php echo(get_option('siteurl')) ?>/wp-admin/options-general.php?page=easy-admin-color-schemes" title="<?php _e('Click here to manage the Admin Color Schemes', $eacs_domain) ?>"><?php _e('Manage &raquo;', $eacs_domain) ?></a></p>
		<?php }
	}

	add_submenu_page('options-general.php', __('Color Schemes', $eacs_domain), __('Color Schemes', $eacs_domain), 'manage_options', 'easy-admin-color-schemes', 'eacs_settings_page');
	$currurlparse = parse_url($_SERVER['REQUEST_URI']);
	$currurl = basename($currurlparse['path']);
	if($currurl == 'user-edit.php' || $currurl == 'profile.php') { add_action('admin_notices', 'eacs_manage_schemes_link', 5000000); }
}
?>